pub enum GcraPolicyError {
ZeroQuota,
QuotaTooLarge {
actual: u64,
maximum: u64,
},
ZeroBurstCapacity,
BurstCapacityTooLarge {
actual: u64,
maximum: u64,
},
ZeroPeriod,
PeriodNotWholeMilliseconds,
PeriodTooLarge {
actual: Duration,
maximum: Duration,
},
RefillDurationTooLarge {
actual_millis: u128,
maximum_millis: u64,
},
}Expand description
An invalid GCRA policy configuration.
Variants
ZeroQuota
The replenishment quota was zero.
QuotaTooLarge
The replenishment quota exceeded the portable backend maximum.
ZeroBurstCapacity
The burst capacity was zero.
BurstCapacityTooLarge
The burst capacity exceeded the portable backend maximum.
Fields
ZeroPeriod
The replenishment period was zero.
PeriodNotWholeMilliseconds
The replenishment period had finer precision than a millisecond.
PeriodTooLarge
The replenishment period exceeded the portable backend maximum.
RefillDurationTooLarge
Filling the complete burst would take longer than the portable maximum.